Thanks for contributing to Gpytranslate! 🎉

Before submitting, please check the following:

* Do the tests still pass?
* You already formatted submitted files with Black (`black .`)
* For new features: Have the examples files and/or readme been updated accordingly?
